@@ -11,6 +11,7 @@ class DisputesClient(FilesClient):
     __DISPUTES_PATH = 'disputes'
     __ACCEPT_PATH = 'accept'
     __EVIDENCE_PATH = 'evidence'
+    __SUBMITTED_PATH = 'submitted'
     __SCHEME_FILES_PATH = "schemefiles"
 
     def __init__(self, api_client: ApiClient, configuration: CheckoutConfiguration):
@@ -41,6 +42,13 @@ class DisputesClient(FilesClient):
         return self._api_client.post(self.build_path(self.__DISPUTES_PATH, dispute_id, self.__EVIDENCE_PATH),
                                      self._sdk_authorization())
 
+    def get_compiled_submitted_evidence(self, dispute_id: str):
+        return self._api_client.get(self.build_path(
+            self.__DISPUTES_PATH, dispute_id,
+            self.__EVIDENCE_PATH,
+            self.__SUBMITTED_PATH),
+            self._sdk_authorization())
+
     def get_dispute_scheme_files(self, dispute_id: str):
         return self._api_client.get(self.build_path(self.__DISPUTES_PATH, dispute_id, self.__SCHEME_FILES_PATH),
                                     self._sdk_authorization())
