@@ -5,10 +5,12 @@ from datetime import datetime
 
 class OAuthAccessToken:
     token: str
+    token_type: str
     expiration_date: datetime
 
-    def __init__(self, token: str, expiration_date: datetime):
+    def __init__(self, token: str, token_type: str, expiration_date: datetime):
         self.token = token
+        self.token_type = token_type
         self.expiration_date = expiration_date
 
     def is_valid(self):
