@@ -6,6 +6,7 @@ from enum import Enum
 from checkout_sdk.common.common import AccountHolder, BankDetails, MarketplaceData, Address, Phone, CustomerRequest, \
     AccountHolderIdentification
 from checkout_sdk.common.enums import PaymentSourceType, Currency, Country, AccountType, ChallengeIndicator
+from checkout_sdk.sessions.sessions import DeliveryTimeframe
 
 
 class AuthorizationType(str, Enum):
@@ -42,6 +43,7 @@ class PaymentType(str, Enum):
     RECURRING = 'Recurring'
     MOTO = 'MOTO'
     INSTALLMENT = 'Installment'
+    UNSCHEDULED = 'Unscheduled'
 
 
 class PaymentDestinationType(str, Enum):
@@ -55,12 +57,15 @@ class Exemption(str, Enum):
     LOW_VALUE = 'low_value'
     SECURE_CORPORATE_PAYMENT = 'secure_corporate_payment'
     TRUSTED_LISTING = 'trusted_listing'
+    TRUSTED_LISTING_PROMPT = 'trusted_listing_prompt'
     TRANSACTION_RISK_ASSESSMENT = 'transaction_risk_assessment'
     THREE_DS_OUTAGE = '3ds_outage'
     SCA_DELEGATION = 'sca_delegation'
     OUT_OF_SCA_SCOPE = 'out_of_sca_scope'
     OTHER = 'other'
     LOW_RISK_PROGRAM = 'low_risk_program'
+    DATA_SHARE = 'data_share'
+    RECURRING_OPERATION = 'recurring_operation'
 
 
 class ThreeDSFlowType(str, Enum):
@@ -120,10 +125,14 @@ class BillingPlanType(str, Enum):
     PRE_APPROVED_PAYMENTS = 'PRE_APPROVED_PAYMENTS'
 
 
+class PanPreference(str, Enum):
+    FPAN = 'fpan'
+    DPAN = 'dpan'
+
+
 class BillingDescriptor:
     name: str
     city: str
-    # Not available on previous
     reference: str
 
 
@@ -150,6 +159,7 @@ class PaymentSender:
 class PaymentCorporateSender(PaymentSender):
     company_name: str
     address: Address
+    reference: str
     reference_type: str
     source_of_funds: str
     identification: AccountHolderIdentification
@@ -161,6 +171,7 @@ class PaymentCorporateSender(PaymentSender):
 class PaymentGovermentSender(PaymentSender):
     company_name: str
     address: Address
+    reference: str
     reference_type: str
     source_of_funds: str
     identification: AccountHolderIdentification
@@ -176,6 +187,7 @@ class PaymentIndividualSender(PaymentSender):
     dob: str
     address: Address
     identification: AccountHolderIdentification
+    reference: str
     reference_type: str
     source_of_funds: str
     date_of_birth: str
@@ -210,6 +222,7 @@ class PaymentRequestCardSource(PaymentRequestSource):
     store_for_future_use: bool
     billing_address: Address
     phone: Phone
+    account_holder: AccountHolder
 
     def __init__(self):
         super().__init__(PaymentSourceType.CARD)
@@ -221,6 +234,7 @@ class PaymentRequestTokenSource(PaymentRequestSource):
     phone: Phone
     stored: bool
     store_for_future_use: bool
+    account_holder: AccountHolder
 
     def __init__(self):
         super().__init__(PaymentSourceType.TOKEN)
@@ -234,10 +248,12 @@ class PaymentRequestNetworkTokenSource(PaymentRequestSource):
     cryptogram: str
     eci: str
     stored: bool
+    store_for_future_use: bool
     name: str
     cvv: str
     billing_address: Address
     phone: Phone
+    account_holder: AccountHolder
 
     def __init__(self):
         super().__init__(PaymentSourceType.NETWORK_TOKEN)
@@ -249,6 +265,7 @@ class PaymentRequestIdSource(PaymentRequestSource):
     payment_method: str
     stored: bool
     store_for_future_use: bool
+    account_holder: AccountHolder
 
     def __init__(self):
         super().__init__(PaymentSourceType.ID)
@@ -277,15 +294,29 @@ class RequestBankAccountSource(PaymentRequestSource):
 
 class RequestCustomerSource(PaymentRequestSource):
     id: str
+    account_holder: AccountHolder
 
     def __init__(self):
         super().__init__(PaymentSourceType.CUSTOMER)
 
 
+class PaymentContextsShippingMethod(str, Enum):
+    DIGITAL = 'Digital'
+    PICK_UP = 'PickUp'
+    BILLING_ADDRESS = 'BillingAddress'
+    OTHER_ADDRESS = 'OtherAddress'
+
+
 class ShippingDetails:
+    first_name: str
+    last_name: str
+    email: str
     address: Address
     phone: Phone
     from_address_zip: str
+    timeframe: DeliveryTimeframe
+    method: PaymentContextsShippingMethod
+    delay: int
 
 
 class ThreeDsRequest:
@@ -298,7 +329,6 @@ class ThreeDsRequest:
     exemption: Exemption
     challenge_indicator: ChallengeIndicator
     allow_upgrade: bool
-    # Not available on Previous
     status: str
     authentication_date: datetime
     authentication_amount: int
@@ -312,6 +342,7 @@ class ThreeDsRequest:
 
 class RiskRequest:
     enabled: bool
+    device_session_id: str
 
 
 class PaymentRecipient:
@@ -353,6 +384,41 @@ class SenderInformation:
     sourceOfFunds: str
 
 
+class PartnerCustomerRiskData:
+    key: str
+    value: str
+
+
+class AccommodationAddress:
+    address_line1: str
+    zip: str
+
+
+class AccommodationGuest:
+    first_name: str
+    last_name: str
+    date_of_birth: str
+
+
+class AccommodationRoom:
+    rate: str
+    number_of_nights_at_room_rate: str
+
+
+class AccommodationData:
+    name: str
+    booking_reference: str
+    check_in_date: str
+    check_out_date: str
+    address: AccommodationAddress
+    state: str
+    country: str
+    city: str
+    number_of_rooms: int
+    guests: list  # AccommodationGuest
+    room: list  # AccommodationRoom
+
+
 class ProcessingSettings:
     order_id: str
     tax_amount: int
@@ -381,11 +447,17 @@ class ProcessingSettings:
     purchase_country: Country
     custom_payment_method_ids: list  # string
     merchant_callback_url: str
+    line_of_business: str
     shipping_delay: int
     shipping_info: list  # ShippingInfo
     dlocal: DLocalProcessingSettings
     senderInformation: SenderInformation
     purpose: str
+    partner_customer_risk_data: list  # PartnerCustomerRiskData
+    accommodation_data: list  # AccommodationData
+    surcharge_amount: int
+    pan_preference: PanPreference
+    provision_network_token: bool
 
 
 class Product:
@@ -408,8 +480,25 @@ class PaymentCustomerRequest(CustomerRequest):
     tax_number: str
 
 
+class PaymentSegment:
+    brand: str
+    business_category: str
+    market: str
+
+
+class PaymentRetryRequest:
+    enabled: bool
+    max_attempts: int
+    end_after_days: int
+
+
 # Request Payment
+class PartialAuthorization:
+    enabled: bool
+
+
 class PaymentRequest:
+    payment_context_id: str
     source: PaymentRequestSource
     amount: int
     currency: Currency
@@ -418,11 +507,13 @@ class PaymentRequest:
     reference: str
     description: str
     authorization_type: AuthorizationType
+    partial_authorization: PartialAuthorization
     capture: bool
     capture_on: datetime
     customer: PaymentCustomerRequest
     billing_descriptor: BillingDescriptor
     shipping: ShippingDetails
+    segment: PaymentSegment
     three_ds: ThreeDsRequest
     processing_channel_id: str
     previous_payment_id: str
@@ -438,6 +529,8 @@ class PaymentRequest:
     processing: ProcessingSettings
     metadata: dict
     items: list  # payments.Product
+    retry: PaymentRetryRequest
+    instruction: PaymentInstruction
 
 
 # Payout Request Source
@@ -488,6 +581,8 @@ class PaymentBankAccountDestination(PaymentRequestDestination):
 class PaymentRequestIdDestination(PaymentRequestDestination):
     id: str
 
+    account_holder: AccountHolder
+
     def __init__(self):
         super().__init__(PaymentDestinationType.ID)
 
@@ -541,6 +636,8 @@ class RefundRequest:
     amount: int
     reference: str
     metadata: dict
+    # Not available on Previous
+    amount_allocations: list  # values of AmountAllocations
 
 
 # Voids
@@ -560,3 +657,9 @@ class FawryProduct:
     quantity: int
     price: int
     description: str
+
+
+class PaymentMethodDetails:
+    display_name: str
+    type: str
+    network: str
